@@ -48,3 +48,36 @@ test_that("get_tiles fails as expected", {
   side_length = 8001
   ))
 })
+
+test_that("specifying SR works", {
+
+  dat <- data.frame(
+    lat = c(44.04905, 44.04911),
+    lng = c(-74.01188, -74.01179)
+  )
+
+  dat <- sf::st_as_sf(dat, coords = c("lng", "lat"))
+  dat <- sf::st_set_crs(dat, 4326)
+
+  output_tif <- vector("list", 4)
+  output_tif[1] <- get_tiles(dat)
+  output_tif[2] <- get_tiles(dat, bboxSR = 4326)
+  output_tif[3] <- get_tiles(dat, imageSR = 4326)
+  output_tif[4] <- get_tiles(dat, bboxSR = 4326, imageSR = 4326)
+
+  expect_equal(
+    brio::read_file_raw(output_tif[[1]]),
+    brio::read_file_raw(output_tif[[2]])
+  )
+
+  expect_equal(
+    brio::read_file_raw(output_tif[[1]]),
+    brio::read_file_raw(output_tif[[3]])
+  )
+
+  expect_equal(
+    brio::read_file_raw(output_tif[[1]]),
+    brio::read_file_raw(output_tif[[4]])
+  )
+
+})
